/********************************************************************************
** Form generated from reading UI file 'bgselectorconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BGSELECTORCONFIG_H
#define UI_BGSELECTORCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_BgSelectorConfig
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QRadioButton *kcfg_RadioTheme;
    QRadioButton *kcfg_RadioColor;
    QRadioButton *kcfg_RadioImage;
    KUrlRequester *kcfg_BgImage;
    KColorButton *kcfg_BgColor;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *BgSelectorConfig)
    {
        if (BgSelectorConfig->objectName().isEmpty())
            BgSelectorConfig->setObjectName("BgSelectorConfig");
        BgSelectorConfig->resize(316, 241);
        gridLayout = new QGridLayout(BgSelectorConfig);
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 4, 0, 1, 1);

        groupBox = new QGroupBox(BgSelectorConfig);
        groupBox->setObjectName("groupBox");
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setObjectName("gridLayout1");
        kcfg_RadioTheme = new QRadioButton(groupBox);
        buttonGroup = new QButtonGroup(BgSelectorConfig);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(kcfg_RadioTheme);
        kcfg_RadioTheme->setObjectName("kcfg_RadioTheme");
        kcfg_RadioTheme->setChecked(true);

        gridLayout1->addWidget(kcfg_RadioTheme, 0, 0, 1, 1);

        kcfg_RadioColor = new QRadioButton(groupBox);
        buttonGroup->addButton(kcfg_RadioColor);
        kcfg_RadioColor->setObjectName("kcfg_RadioColor");

        gridLayout1->addWidget(kcfg_RadioColor, 1, 0, 1, 1);

        kcfg_RadioImage = new QRadioButton(groupBox);
        buttonGroup->addButton(kcfg_RadioImage);
        kcfg_RadioImage->setObjectName("kcfg_RadioImage");

        gridLayout1->addWidget(kcfg_RadioImage, 2, 0, 1, 1);

        kcfg_BgImage = new KUrlRequester(groupBox);
        kcfg_BgImage->setObjectName("kcfg_BgImage");
        kcfg_BgImage->setEnabled(false);

        gridLayout1->addWidget(kcfg_BgImage, 2, 1, 1, 1);

        kcfg_BgColor = new KColorButton(groupBox);
        kcfg_BgColor->setObjectName("kcfg_BgColor");
        kcfg_BgColor->setEnabled(false);

        gridLayout1->addWidget(kcfg_BgColor, 1, 1, 1, 1);


        gridLayout->addWidget(groupBox, 3, 0, 1, 1);


        retranslateUi(BgSelectorConfig);
        QObject::connect(kcfg_RadioColor, SIGNAL(toggled(bool)), kcfg_BgColor, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_RadioImage, SIGNAL(toggled(bool)), kcfg_BgImage, SLOT(setEnabled(bool)));
        QObject::connect(buttonGroup, &QButtonGroup::buttonToggled, groupBox, qOverload<>(&QGroupBox::update));

        QMetaObject::connectSlotsByName(BgSelectorConfig);
    } // setupUi

    void retranslateUi(QWidget *BgSelectorConfig)
    {
        kcfg_RadioTheme->setText(tr2i18n("&Theme", nullptr));
        kcfg_RadioColor->setText(tr2i18n("&Color", nullptr));
        kcfg_RadioImage->setText(tr2i18n("&Image", nullptr));
        (void)BgSelectorConfig;
    } // retranslateUi

};

namespace Ui {
    class BgSelectorConfig: public Ui_BgSelectorConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BGSELECTORCONFIG_H

