/********************************************************************************
** Form generated from reading UI file 'gameconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GAMECONFIG_H
#define UI_GAMECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GameConfig
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_ShowBoundLines;
    QCheckBox *kcfg_EnableAnimation;
    QCheckBox *kcfg_EnableHighlight;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *GameConfig)
    {
        if (GameConfig->objectName().isEmpty())
            GameConfig->setObjectName("GameConfig");
        GameConfig->resize(400, 300);
        vboxLayout = new QVBoxLayout(GameConfig);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_ShowBoundLines = new QCheckBox(GameConfig);
        kcfg_ShowBoundLines->setObjectName("kcfg_ShowBoundLines");

        vboxLayout->addWidget(kcfg_ShowBoundLines);

        kcfg_EnableAnimation = new QCheckBox(GameConfig);
        kcfg_EnableAnimation->setObjectName("kcfg_EnableAnimation");

        vboxLayout->addWidget(kcfg_EnableAnimation);

        kcfg_EnableHighlight = new QCheckBox(GameConfig);
        kcfg_EnableHighlight->setObjectName("kcfg_EnableHighlight");

        vboxLayout->addWidget(kcfg_EnableHighlight);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(GameConfig);

        QMetaObject::connectSlotsByName(GameConfig);
    } // setupUi

    void retranslateUi(QWidget *GameConfig)
    {
#if QT_CONFIG(whatsthis)
        kcfg_ShowBoundLines->setWhatsThis(tr2i18n("Show bound lines", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowBoundLines->setText(tr2i18n("Show bound lines", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_EnableAnimation->setWhatsThis(tr2i18n("Enable animation", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_EnableAnimation->setText(tr2i18n("Enable animation", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_EnableHighlight->setWhatsThis(tr2i18n("Enable highlight", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_EnableHighlight->setText(tr2i18n("Enable highlight", nullptr));
        (void)GameConfig;
    } // retranslateUi

};

namespace Ui {
    class GameConfig: public Ui_GameConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GAMECONFIG_H

